==> speech-analytic-testing_0.10.2_database.tar.gz: database/mssql/procedures/ReportByDetailAgent.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO



CREATE PROCEDURE [dbo].[ReportByDetailAgent] (
	@VCC varchar(50) = NULL, 
	@Campana varchar(50) = NULL , 
	@Plan varchar(50) = NULL,
	@Formato varchar(50), 
	-- @FechaInicial varchar(50) = NULL , 
	-- @FechaFinal varchar(50) = NULL , 
	@StartDate DateTime = NULL , 
	@EndDate DateTime = NULL , 
	@IdAuditor varchar(50) = NULL ,
	@IdAgente varchar(50) = NULL
) AS
  DECLARE @cols varchar(max)
  DECLARE @query varchar(max)
  
  -- ReportByDetailAgent 'allegro','entrantes','Plan_2_nov01-0356','nov01-0356','20191001','20191201','isidoro','icagente3'
  SET NOCOUNT ON

  SELECT
    * INTO #TempEvaluationResult
  FROM (
  SELECT
	EP.[Instance]														'VCC',
    EP.Description														AS 'DescriptionPlan',
    EF.Description														AS 'DescriptionFormat',
    GP.Description + '-' + SGP.Description + '-' + A.Title				AS 'Ability',
    ER.AgentDescription,
    ER.CampaignDescription,
    ER.IdInteraction,
    ER.Qualification,
	AEP.[AutomaticScore],
	AEP.[ManualScore],
	Format(ER.EvaluationDate, 'dd/MM/yyyy hh:mm:ss')					AS 'EvaluationDate',
    ER.IdAuditor,
	EP.Evaluation_Mode	
  FROM EvaluationResult (NOLOCK) ER
  LEFT JOIN EvaluationFormat EF
    ON ER.IdEvaluationFormat = EF.ID
  LEFT JOIN Ability (NOLOCK) A
    ON A.ID = ER.IdAbility
  LEFT JOIN EvaluationPlan (NOLOCK) EP
    ON EP.ID = ER.IdEvaluationPlan
	INNER JOIN [dbo].[AuditorEvaluationPlan] AEP (NOLOCK) 
		ON AEP.[Instance] = ER.[Instance]
			AND AEP.[IdEvaluationPlan] =  ER.[IdEvaluationPlan]
			AND AEP.[IdInteraction] = ER.[IdInteraction]
			AND AEP.[IdAuditor] =  ER.[IdAuditor]
  LEFT JOIN [Group] (NOLOCK) GP
    ON GP.ID = ER.IdGroup
  LEFT JOIN SubGroup (NOLOCK) SGP
    ON SGP.ID = ER.IdSubGroup
  WHERE 
	ER.Instance LIKE CASE
		WHEN @VCC IS NOT NULL THEN @VCC
		ELSE ER.Instance
	  END
  AND 
	EF.Description LIKE CASE
		WHEN @Formato IS NOT NULL THEN @Formato
		ELSE EF.Description
	  END
  AND 
	EP.Description LIKE CASE
		WHEN @Plan IS NOT NULL THEN @Plan
		ELSE EP.Description
	END
  AND 
	ER.CampaignDescription LIKE CASE
		WHEN @Campana IS NOT NULL THEN @Campana
		ELSE ER.CampaignDescription
	  END
  AND 
	ER.AgentDescription LIKE CASE
		WHEN @IdAgente IS NOT NULL THEN @IdAgente
		ELSE ER.AgentDescription
	  END
  AND 
	ER.IdAuditor LIKE CASE
		WHEN @IdAuditor IS NOT NULL THEN @IdAuditor
		ELSE ER.IdAuditor
	  END
  AND ER.EvaluationDate >=
                          CASE
                            WHEN @StartDate IS NOT NULL THEN @StartDate
                            ELSE '19800101'
                          END
  AND ER.EvaluationDate <
                         CASE
                           WHEN @EndDate IS NOT NULL THEN @EndDate + ' 23:59'
                           ELSE '20500101'
                         END
	--AND EP.[Status] = 7
	) a



  SET @cols = STUFF((SELECT DISTINCT
    ',' + QUOTENAME(Ability)
  FROM #TempEvaluationResult
  FOR xml PATH (''), TYPE)
  .value('.', 'varchar(Max)')
  , 1, 1, '')
  --Select @cols
  IF @cols IS NOT NULL
  BEGIN

    DECLARE @type varchar(max)=(Select Top 1 Evaluation_Mode From #TempEvaluationResult)

    DECLARE @Total varchar(max) = STUFF((SELECT DISTINCT
      '+ ISNULL(' + QUOTENAME(Ability) + ',0)'
    FROM #TempEvaluationResult
    FOR xml PATH (''), TYPE)
    .value('.', 'varchar(Max)')
    , 1, 1, '')
    --SELECT @type
	If @type = 'M'
	BEGIN
    SET @query = ' 
				Select p.[VCC]							AS [VCC],
						p.DescriptionPlan				As [Plan],
						p.DescriptionFormat				As Formato,
						p.AgentDescription				As Agente,
  						p.CampaignDescription			As [Campana],
						p.IdInteraction					As [Interaccion],
						p.EvaluationDate				As [Fecha Evaluacion],
						p.IdAuditor						As Auditor,
						InteractionDuration				as [Tiempo duracion], 
						null							As [Telefono],
						InteractionDateStart			As [Fecha Inicio],
						null							As [Categoria],
						(' + @Total + ')				As COLUMN_TOTAL_SCORE, 
						p.[AutomaticScore]				AS COLUMN_AUTOMATIC_SCORE,
						p.[ManualScore]					AS COLUMN_MANUAL_SCORE,
						' + @cols + ' 
					from 
				( select VCC,
							DescriptionPlan,
						  DescriptionFormat,
						  Ability,
						  AgentDescription,
						  CampaignDescription,
						  IdInteraction,
						  EvaluationDate,
						  Qualification,
						  AutomaticScore,
						  ManualScore,
						  IdAuditor			
					from #TempEvaluationResult
			   ) x
				pivot 
				( 
					 max(Qualification)
					for Ability in (' + @cols + ')
				) p 
				Left Join (
				Select Distinct IdInteraction,InteractionDuration,InteractionDateStart From InteractionEvaluationPlan (Nolock)
				) as A On
				A.IdInteraction = p.IdInteraction '
    END
	ELSE 
	BEGIN
    SET @query = ' 
				Select p.[VCC]							AS [VCC],
						p.DescriptionPlan				As [Plan],
						p.DescriptionFormat				As Formato,
						p.AgentDescription				As Agente,
  						p.CampaignDescription			As [Campana] ,
						p.IdInteraction					As [Interaccion] ,
						p.EvaluationDate				As [Fecha Evaluacion],
						p.IdAuditor						As Auditor,
						A.DurationTime					as [Tiempo Duracion],
						A.Number						As [Telefono] ,
						A.StartDate						As [Fecha Inicio] ,
						A.Category1						As Categoria ,
						(' + @Total + ')				As COLUMN_TOTAL_SCORE,
						p.[AutomaticScore]				AS COLUMN_AUTOMATIC_SCORE,
						p.[ManualScore]					AS COLUMN_MANUAL_SCORE,
						' + @cols + ' from 
				( select VCC,
							DescriptionPlan,
						  DescriptionFormat,
						  Ability,
						  AgentDescription,
						  CampaignDescription,
						  IdInteraction,
						  EvaluationDate,
						  Qualification,
						  AutomaticScore,
						  ManualScore,
						  IdAuditor			
					from #TempEvaluationResult
			   ) x
				pivot 
				( 
					 max(Qualification)
					for Ability in (' + @cols + ')
				) p 
				INNER Join Audio as A 
				On A.[VCC] = p.[VCC]
					AND A.ID = p.IdInteraction'
	END
	--Print(@query)
    EXECUTE (@query)
    DROP TABLE #TempEvaluationResult
  END
  ELSE
  BEGIN
    SELECT
      '' AS [Plan],
      '' AS Formato,
      '' AS Agente,
      '' AS [Campana],
      '' AS [Interaccion],
      '' AS EvaluationDate,
      '' AS IdAuditor
  END
  
  SET NOCOUNT OFF
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO

==> speech-analytic-testing_0.11.0_database.tar.gz: database/mssql/procedures/ReportByDetailAgent.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO


CREATE PROCEDURE [dbo].[ReportByDetailAgent] (
	@VCC varchar(50) = NULL, 
	@Campana varchar(50) = NULL , 
	@Plan varchar(50) = NULL,
	@Formato varchar(50), 
	-- @FechaInicial varchar(50) = NULL , 
	-- @FechaFinal varchar(50) = NULL , 
	@StartDate DateTime = NULL , 
	@EndDate DateTime = NULL , 
	@IdAuditor varchar(50) = NULL ,
	@IdAgente varchar(50) = NULL
) AS
  DECLARE @cols varchar(max) 
  DECLARE @query varchar(max)
  
  -- ReportByDetailAgent 'allegro','entrantes','Plan_2_nov01-0356','nov01-0356','20191001','20191201','isidoro','icagente3'
  SET NOCOUNT ON

  SELECT
    * INTO #TempEvaluationResult
  FROM (
  SELECT
	EP.[Instance]														'VCC',
    EP.Description														AS 'DescriptionPlan',
    EF.Description														AS 'DescriptionFormat',
    (
		GP.Description
		+ '-' 
		+ SGP.Description
		+ '-' 
		+ A.Title
	)																	AS 'Ability', --Collate SQL_Latin1_General_CP1253_CI_AI
    ER.AgentDescription,
    ER.CampaignDescription,
    ER.IdInteraction,
    ISNULL(ER.Qualification, 0)											AS 'Qualification',
	AEP.[AutomaticScore],
	AEP.[ManualScore],
	--Format(ER.EvaluationDate, 'dd/MM/yyyy hh:mm:ss')					AS 'EvaluationDate',
	Format(AEP.[TimeStamp], 'dd/MM/yyyy')					AS 'EvaluationDate',
    ER.IdAuditor,
	EP.Evaluation_Mode	
  FROM EvaluationResult (NOLOCK) ER
  INNER JOIN EvaluationFormat EF
    ON ER.IdEvaluationFormat = EF.ID
  INNER JOIN Ability (NOLOCK) A
    ON A.[Instance] = ER.[Instance]
		AND A.ID = ER.IdAbility
  INNER JOIN EvaluationPlan (NOLOCK) EP
    ON EP.ID = ER.IdEvaluationPlan
	INNER JOIN [dbo].[AuditorEvaluationPlan] AEP (NOLOCK) 
		ON AEP.[Instance] = ER.[Instance]
			AND AEP.[IdEvaluationPlan] =  ER.[IdEvaluationPlan]
			AND AEP.[IdInteraction] = ER.[IdInteraction]
			AND AEP.[IdAuditor] =  ER.[IdAuditor]
  LEFT JOIN [Group] (NOLOCK) GP
    ON GP.ID = ER.IdGroup
  LEFT JOIN SubGroup (NOLOCK) SGP
    ON SGP.ID = ER.IdSubGroup
  WHERE 
	ER.Instance LIKE CASE
		WHEN @VCC IS NOT NULL THEN @VCC
		ELSE ER.Instance
	  END
  AND 
	EF.Description LIKE CASE
		WHEN @Formato IS NOT NULL THEN @Formato
		ELSE EF.Description
	  END
  AND 
	EP.Description LIKE CASE
		WHEN @Plan IS NOT NULL THEN @Plan
		ELSE EP.Description
	END
  AND 
	ER.CampaignDescription LIKE CASE
		WHEN @Campana IS NOT NULL THEN @Campana
		ELSE ER.CampaignDescription
	  END
  AND 
	ER.AgentDescription LIKE CASE
		WHEN @IdAgente IS NOT NULL THEN @IdAgente
		ELSE ER.AgentDescription
	  END
  AND 
	ER.IdAuditor LIKE CASE
		WHEN @IdAuditor IS NOT NULL THEN @IdAuditor
		ELSE ER.IdAuditor
	  END
  AND AEP.[TimeStamp] >=
                          CASE
                            WHEN @StartDate IS NOT NULL THEN @StartDate
                            ELSE '19800101'
                          END
  AND AEP.[TimeStamp] <
                         CASE
                           WHEN @EndDate IS NOT NULL THEN @EndDate + ' 23:59'
                           ELSE '20500101'
                         END
  --AND EP.[Status] = 7
  AND AEP.[Completed] = 1
	) a

	--select * from #TempEvaluationResult ORDER BY IdInteraction


  SET @cols = STUFF((SELECT DISTINCT
    ',' + QUOTENAME(Ability) 
  FROM #TempEvaluationResult
  FOR xml PATH (''), TYPE)
  .value('.', 'varchar(Max)')
  , 1, 1, '')
  --Select @cols
  IF @cols IS NOT NULL
  BEGIN

    DECLARE @type varchar(max)=(Select Top 1 Evaluation_Mode From #TempEvaluationResult)

    DECLARE @Total varchar(max) = STUFF((SELECT DISTINCT
      '+ ISNULL(' + QUOTENAME(Ability) + ',0)'
    FROM #TempEvaluationResult
    FOR xml PATH (''), TYPE)
    .value('.', 'varchar(Max)')
    , 1, 1, '')
    --SELECT @type
	If @type = 'M'
	BEGIN
    SET @query = ' 
				Select p.[VCC]							AS [VCC],
						p.DescriptionPlan				As [Plan],
						p.DescriptionFormat				As Formato,
						p.AgentDescription				As Agente,
  						p.CampaignDescription			As [Campana],
						p.IdInteraction					As [Interaccion],
						p.EvaluationDate				As [Fecha Evaluacion],
						p.IdAuditor						As Auditor,
						InteractionDuration				as [Tiempo duracion], 
						null							As [Telefono],
						InteractionDateStart			As [Fecha Inicio],
						null							As [Categoria],
						(' + @Total + ')				As COLUMN_TOTAL_SCORE, 
						p.[AutomaticScore]				AS COLUMN_AUTOMATIC_SCORE,
						p.[ManualScore]					AS COLUMN_MANUAL_SCORE,
						' + @cols + ' 
					from 
				( select VCC,
							DescriptionPlan,
						  DescriptionFormat,
						  Ability,
						  AgentDescription,
						  CampaignDescription,
						  IdInteraction,
						  EvaluationDate,
						  Qualification,
						  AutomaticScore,
						  ManualScore,
						  IdAuditor			
					from #TempEvaluationResult
			   ) x
				pivot 
				( 
					 max(Qualification)
					for Ability in (' + @cols + ')
				) p 
				Left Join (
				Select Distinct IdInteraction,InteractionDuration,InteractionDateStart From InteractionEvaluationPlan (Nolock) 
				) as A On
				A.IdInteraction = p.IdInteraction '
    END
	ELSE 
	BEGIN
    SET @query = ' 
				Select p.[VCC]							AS [VCC],
						p.DescriptionPlan				As [Plan],
						p.DescriptionFormat				As Formato,
						p.AgentDescription				As Agente,
  						p.CampaignDescription			As [Campana] ,
						p.IdInteraction					As [Interaccion] ,
						p.EvaluationDate				As [Fecha Evaluacion],
						p.IdAuditor						As Auditor,
						A.DurationTime					as [Tiempo Duracion],
						A.Number						As [Telefono] ,
						A.StartDate						As [Fecha Inicio] ,
						A.Category1						As Categoria ,
						(' + @Total + ')				As COLUMN_TOTAL_SCORE,
						p.[AutomaticScore]				AS COLUMN_AUTOMATIC_SCORE,
						p.[ManualScore]					AS COLUMN_MANUAL_SCORE,
						' + @cols + ' 
					from ( 
						select VCC,
								DescriptionPlan,
								DescriptionFormat,
								Ability,
								AgentDescription,
								CampaignDescription,
								IdInteraction,
								EvaluationDate,
								Qualification,
								AutomaticScore,
								ManualScore,
								IdAuditor			
							from #TempEvaluationResult
					) x pivot 
					( 
						 max(Qualification)
						for Ability in (' + @cols + ')
					) p 
					LEFT Join Audio as A 
						On A.[VCC] = p.[VCC]
							AND A.ID = p.IdInteraction'
	END
	--Print(@query)
    EXECUTE (@query)
    DROP TABLE #TempEvaluationResult
  END
  ELSE
  BEGIN
    SELECT
      '' AS [Plan],
      '' AS Formato,
      '' AS Agente,
      '' AS [Campana],
      '' AS [Interaccion],
      '' AS EvaluationDate,
      '' AS IdAuditor
  END
  
  SET NOCOUNT OFF
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO
